@@ -144,12 +144,12 @@ plot_pmx.residual <- function(x, dx, ...) {
         theme(aspect.ratio = 1)
     }
 
-    if (!(exists("ranges", gp) && is.null(gp$y))) {
+    if (is.null(gp$ranges) || is.null(gp$ranges$y)) {
       if (aess$y %in% c("NPDE", "IWRES") && !gp$scale_y_log10 && is.null(x$trans)) {
         mm <- max(dx[, aess$y, with = FALSE], na.rm = TRUE)
         if (is.null(gp$ranges)) {
           gp$ranges <- list(y = c(-mm, mm))
-        } else {
+        } else  {
           gp$ranges$y <- c(-mm, mm)
         }
       }
